@@ -1,12 +1,11 @@
 """ Assessment Urls. """
 
-
-from django.conf.urls import url
+from django.urls import re_path
 
 from openassessment.assessment import views
 
 urlpatterns = [
-    url(
+    re_path(
         r'^(?P<student_id>[^/]+)/(?P<course_id>[^/]+)/(?P<item_id>[^/]+)$',
         views.get_evaluations_for_student_item
     ),
